EasyValidators class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
age(
String? value) → String? -
confirmPassword(
String? value, String original) → String? -
email(
String? value) → String? -
maxLength(
String? value, int max, {String fieldName = 'Field'}) → String? -
minLength(
String? value, int min, {String fieldName = 'Field'}) → String? -
name(
String? value, {String fieldName = 'Name'}) → String? -
notEmpty(
String? value, {String fieldName = 'Field'}) → String? -
password(
String? value, {int minLength = 6}) → String? -
phone(
String? value) → String?